require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmclassification',
  dscmeta_resource_friendly_name: 'FSRMClassification',
  dscmeta_resource_name: 'DSC_FSRMClassification',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: %q{
    The DSC FSRMClassification resource type.
    Automatically generated from version 2.5.0
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_schedulerunduration: {
      type: "Optional[Integer[-2147483648, 2147483647]]",
      desc: %q{
        The maximum number of hours the FSRM Classification can run for. Setting this to -1 will disable this.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_continuouslogsize: {
      type: "Optional[Integer[0, 4294967295]]",
      desc: %q{
        The maximum number of KB that can be used for the continuous mode log file.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_schedulemonthly: {
      type: "Optional[Array[Integer[0, 4294967295]]]",
      desc: %q{
        An array of days of the month the FSRM Classification should run on.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
    dsc_id: {
      type: "String",
      desc: %q{
        This is a unique identifier for this resource.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletime: {
      type: "Optional[String]",
      desc: %q{
        A string containing the time of day the FSRM Classification should run at.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_continuouslog: {
      type: "Optional[Boolean]",
      desc: %q{
        Enable FSRM Classification continuous mode logging.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excludenamespace: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of Namespaces that will be excluded from FSRM Classification.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_scheduleweekly: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of named days of the week the FSRM Classification should run on.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_continuous: {
      type: "Optional[Boolean]",
      desc: %q{
        Enable FSRM Classification continuous mode for new files.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
