require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmclassificationproperty',
  dscmeta_resource_friendly_name: 'FSRMClassificationProperty',
  dscmeta_resource_name: 'DSC_FSRMClassificationProperty',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: %q{
    The DSC FSRMClassificationProperty resource type.
    Automatically generated from version 2.5.0
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_parameters: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of parameters in the format <name>=<value> that can be used by the File Classification Infrastructure.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_type: {
      type: "Enum['OrderedList', 'MultiChoice', 'SingleChoice', 'String', 'MultiString', 'Integer', 'YesNo', 'DateTime']",
      desc: %q{
        The type of the FSRM Classification Property.
      },

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        Specifies whether the FSRM Classification Property should exist.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: "Optional[String]",
      desc: %q{
        The description for the FSRM Classification Property.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "String",
      desc: %q{
        The name of the FSRM Classification Property.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_possiblevalue: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of possible values that this FSRM Classification Property can take on.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: "Optional[String]",
      desc: %q{
        The display name for the FSRM Classification Property.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
