require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmfilescreen',
  dscmeta_resource_friendly_name: 'FSRMFileScreen',
  dscmeta_resource_name: 'DSC_FSRMFileScreen',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: %q{
    The DSC FSRMFileScreen resource type.
    Automatically generated from version 2.5.0
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        Specifies whether the FSRM File Screen should exist.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includegroup: {
      type: "Optional[Array[String]]",
      desc: %q{
        An array of File Groups to include in this File Screen.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: "Optional[String]",
      desc: %q{
        An optional description for this FSRM File Screen.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_template: {
      type: "Optional[String]",
      desc: %q{
        The name of the FSRM File Screen Template to apply to this path.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_active: {
      type: "Optional[Boolean]",
      desc: %q{
        Boolean setting that controls if server should fail any I/O operations if the File Screen is violated.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: "String",
      desc: %q{
        The path this FSRM File Screen applies to.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_matchestemplate: {
      type: "Optional[Boolean]",
      desc: %q{
        Causes the template to use only the template name and Active and Ignore Groups parameters.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
