require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmfilescreenaction',
  dscmeta_resource_friendly_name: 'FSRMFileScreenAction',
  dscmeta_resource_name: 'DSC_FSRMFileScreenAction',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: %q{
    The DSC FSRMFileScreenAction resource type.
    Automatically generated from version 2.5.0
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_killtimeout: {
      type: "Optional[Integer[-2147483648, 2147483647]]",
      desc: %q{
        Int containing kill timeout of the command. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_workingdirectory: {
      type: "Optional[String]",
      desc: %q{
        The type of event created. Required when Type is Event.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_body: {
      type: "Optional[String]",
      desc: %q{
        The body text of the e-mail or event. Required when Type is Email or Event.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_subject: {
      type: "Optional[String]",
      desc: %q{
        The subject of the e-mail sent. Required when Type is Email.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_command: {
      type: "Optional[String]",
      desc: %q{
        The Command to execute. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runlimitinterval: {
      type: "Optional[Integer[-2147483648, 2147483647]]",
      desc: %q{
        Int containing the run limit interval of the command. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_mailto: {
      type: "Optional[String]",
      desc: %q{
        The mail to of the e-mail sent. Required when Type is Email.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Enum['Email', 'Event', 'Command', 'Report']",
      desc: %q{
        The type of FSRM Action.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        Specifies whether the FSRM Action should exist.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reporttypes: {
      type: "Optional[Array[String]]",
      desc: %q{
        Array of Reports to create. Required when Type is Report.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_mailbcc: {
      type: "Optional[String]",
      desc: %q{
        The mail BCC of the e-mail sent. Required when Type is Email.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_commandparameters: {
      type: "Optional[String]",
      desc: %q{
        The Command Parameters. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eventtype: {
      type: "Optional[Enum['None', 'Information', 'Warning', 'Error']]",
      desc: %q{
        The type of event created. Required when Type is Event.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailcc: {
      type: "Optional[String]",
      desc: %q{
        The mail CC of the e-mail sent. Required when Type is Email.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securitylevel: {
      type: "Optional[Enum['None', 'LocalService', 'NetworkService', 'LocalSystem']]",
      desc: %q{
        The security level the command runs under. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: "String",
      desc: %q{
        The path of the FSRM File Screen the action applies to.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_shouldlogerror: {
      type: "Optional[Boolean]",
      desc: %q{
        The working directory of the command. Required when Type is Command.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
